==> nextcloud-24.0.7.tar.bz2: nextcloud/apps/photos/l10n/de.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Öffentlicher Link",
    "Photos" : "Fotos",
    "Your memories under your control" : "Deine Erinnerungen unter deiner Kontrolle",
    "All media" : "Alle Medien",
    "Videos" : "Videos",
    "Albums" : "Alben",
    "Collaborative albums" : "Gemeinsame Alben",
    "People" : "Personen",
    "Folders" : "Ordner",
    "Favorites" : "Favoriten",
    "On this day" : "An diesem Tag",
    "Shared with you" : "Mit dir geteilt",
    "Tags" : "Schlagworte",
    "Locations" : "Orte",
    "Photos settings" : "Fotos-Einstellungen",
    "Mark selection as favorite" : "Auswahl als Favoriten markieren",
    "Add selection to favorites" : "Auswahl zu Favoriten hinzufügen",
    "Remove selection from favorites" : "Auswahl aus Favoriten entfernen",
    "Name of the album" : "Name des Albums",
    "Location of the album" : "Ort des Albums",
    "Go back to the previous view." : "Zur vorherigen Ansicht zurückgehen",
    "Back" : "Zurück",
    "Go to the add collaborators view." : "Zur Ansicht Mitbearbeitende-hinzufügen wechseln.",
    "Add collaborators" : "Mitbearbeitende hinzufügen",
    "Save." : "Speichern",
    "Create the album." : "Das Album erstellen",
    "Save" : "Speichern",
    "Create album" : "Album erstellen",
    "Back to the new album form." : "Zurück zur neuen Albumform",
    "Add to Album" : "Zum Album hinzufügen",
    "Create a new album." : "Ein neues Album erstellen",
    "Create new album" : "Neues Album erstellen",
    "New album" : "Neues Album",
    "_%n item_::_%n photos and videos_" : ["%n Foto oder Video","%n Fotos und Videos"],
    "_Share with %n user_::_Share with %n users_" : ["Mit %n Nutzer teilen","Mit %n Nutzern teilen"],
    "Add people or groups who can edit your album" : "Personen oder Gruppen hinzufügen, die dein Album bearbeiten können",
    "Search for collaborators" : "Suche nach Mitbearbeitenden",
    "Search people or groups" : "Nach Benutzer oder Gruppen suchen",
    "Add {collaboratorLabel} to the collaborators list" : "{collaboratorLabel} zur Liste der Mitarbeitenden hinzufügen",
    "No collaborators available" : "Keine Mitarbeitenden verfügbar",
    "Remove {collaboratorLabel} from the collaborators list" : "{collaboratorLabel} aus der Liste der Mitarbeitenden löschen",
    "Copy the public link" : "Den öffentlichen Link kopieren",
    "Public link copied!" : "Öffentlicher Link kopiert",
    "Copy public link" : "Öffentlichen Link kopieren",
    "Delete the public link" : "Den öffentlichen Link löschen",
    "Share via public link" : "Als öffentlichen Link teilen",
    "Failed to fetch collaborators list." : "Liste der Mitbearbeitenden konnte nicht abgerufen werden.",
    "Failed to fetch album." : "Album konnte nicht abgerufen werden.",
    "Failed to update album." : "Album konnte nicht aktualisiert werden.",
    "This collection does not exist" : "Diese Sammlung existiert nicht",
    "An error occurred" : "Es ist ein Fehler aufgetreten",
    "_%n photos_::_%n photos_" : ["%n Foto","%n Fotos"],
    "Select image {imageName}" : "Bild {imageName} auswählen",
    "The file is in the favorites" : "Die Datei ist in den Favoriten",
    "Open the full size \"{name}\" image" : "Bild \"{name}\" in Originalgröße öffnen",
    "There are no photos or videos yet!" : "Es gibt noch keine Fotos oder Videos!",
    "Add to {destination}" : "Hinzufügen zu {destination}",
    "Open the \"{name}\" sub-directory" : "Öffne den \"{name}\" Unterordner",
    "Back to {folder}" : "Zurück zu {folder}",
    "Share this folder" : "Diesen Ordner teilen",
    "_{years} year ago_::_{years} years ago_" : ["Vor {years} Jahr","Vor {years} Jahren"],
    "Enable squared photos view" : "Quadratische Fotoansicht aktivieren",
    "Default Photos upload and Albums location" : "Standardspeicherort für das Hochladen von Fotos und Alben",
    "Select the default location for your media" : "Standardspeicherort für deine Medien auswählen",
    "Invalid location selected" : "Ungültiger Speicherort ausgewählt",
    "View" : "Ansicht",
    "Photos directory" : "Verzeichnis für Fotos",
    "_%n photo_::_%n photos_" : ["%n Foto","%n Fotos"],
    "Manage collaborators for this album" : "Mitbearbeitende für dieses Album verwalten",
    "Open actions menu" : "Aktionsmenü öffnen",
    "Edit album details" : "Albumdetails bearbeiten",
    "Download all files in album" : "Alle Dateien im Album herunterladen",
    "Delete album" : "Album löschen",
    "Download selected files" : "Ausgewählte Dateien herunterladen",
    "Remove selection from album" : "Auswahl aus Album entfernen",
    "This album does not have any photos or videos yet!" : "Dieses Album enthält noch keine Fotos oder Videos!",
    "Add photos to this album" : "Fotos zu diesem Album hinzufügen",
    "Add photos to the album" : "Fotos zum Album hinzufügen",
    "Manage collaborators" : "Mitarbeitende verwalten",
    "Save collaborators for this album." : "Mitbearbeitende für dieses Album speichern.",
    "Cover photo for album {albumName}" : "Titelbild für Album {albumName}",
    "There is no album yet!" : "Es gibt noch kein Album!",
    "This person could not be found" : "Diese Person konnte nicht gefunden werden",
    "Rename person" : "Person umbenennen",
    "Merge with different person" : "Mit einer anderen Person zusammenführen",
    "Download selected photos" : "Ausgwählte Fotos herunterladen",
    "Favorite" : "Favorit",
    "Remove from favorites" : "Von Favoriten entfernen",
    "Remove person" : "Person entfernen",
    "Name of this person" : "Name dieser Person",
    "Merge person" : "Person zusammenführen",
    "_Remove photo from person_::_Remove photos from person_" : ["Foto von Person entfernen","Fotos von Person entfernen"],
    "This might take some time depending on the size of your photo library." : "Dies kann je nach Größe deiner Fotobibliothek einige Zeit dauern.",
    "Recognized people will show up here" : "Erkannte Menschen werden hier angezeigt werden",
    "This folder does not exist" : "Dieser Ordner existiert nicht",
    "Loading folders …" : "Lade Ordner…",
    "No photos in here" : "Keine Fotos vorhanden",
    "Failed to fetch albums list." : "Albumliste konnte nicht geladen werden.",
    "Shared albums" : "Geteilte Alben",
    "Cover photo for shared album {albumName}." : "Titelbild für das geteilte Album {albumName}.",
    "Back to tags overview" : "Zurück zur Schlagwortübersicht",
    "No photos with this tag yet" : "Noch keine Fotos mit diesem Schlagwort",
    "No tags yet" : "Noch keine Schlagworte vorhanden",
    "Photos with tags will show up here" : "Fotos mit Tags werden hier angezeigt",
    "Popular tags" : "Beliebte Schlagwörter",
    "Add" : "Hinzufügen",
    "Create a new album" : "Neues Album erstellen",
    "Add selection to an album" : "Auswahl einem Album hinzufügen",
    "Add to album" : "Zum Album hinzufügen",
    "Delete selection" : "Auswahl löschen",
    "Failed to fetch faces list." : "Liste mit Gesichter konnte nicht geladen werden.",
    "All your media" : "Alle deine Medien",
    "Tagged photos" : "Fotos mit Tags",
    "Failed to create {albumName}." : "{albumName} konnte nicht erstellt werden.",
    "Failed to rename {currentAlbumName} to {newAlbumName}." : "{currentAlbumName} konnte nicht in {newAlbumName} umbenannt werden.",
    "Failed to rename {oldName} to {faceName}." : "{oldName} konnte nicht in {faceName} umbenannt werden.",
    "Failed to delete {faceName}." : "{faceName} konnte nicht gelöscht werden.",
    "Failed to delete {fileId}." : "{fileId} konnte nicht gelöscht werden.",
    "Failed to delete {fileName}." : "{fileName} konnte nicht gelöscht werden.",
    "Failed to set favorite state for {fileId}." : "Fehler beim Festlegen des Favoritenstatus für {fileId}.",
    "Failed to set favorite state for {fileName}." : "Fehler beim Festlegen des Favoritenstatus für {fileName}.",
    "Your photos" : "Deine Fotos",
    "Your videos" : "Deine Videos",
    "Your folders" : "Deine Ordner",
    "Settings" : "Einstellungen"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-28.0.6.tar.bz2: nextcloud/apps/photos/l10n/de.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Öffentlicher Link",
    "Photos" : "Fotos",
    "Your memories under your control" : "Deine Erinnerungen unter deiner Kontrolle",
    "All media" : "Alle Medien",
    "Videos" : "Videos",
    "Albums" : "Alben",
    "Collaborative albums" : "Gemeinsame Alben",
    "People" : "Personen",
    "Folders" : "Ordner",
    "Favorites" : "Favoriten",
    "On this day" : "An diesem Tag",
    "Shared with you" : "Mit dir geteilt",
    "Tags" : "Schlagworte",
    "Places" : "Orte",
    "Map" : "Karte",
    "Photos settings" : "Fotos-Einstellungen",
    "Mark selection as favorite" : "Auswahl als Favoriten markieren",
    "Add selection to favorites" : "Auswahl zu Favoriten hinzufügen",
    "Remove selection from favorites" : "Auswahl aus Favoriten entfernen",
    "Name of the album" : "Name des Albums",
    "Location of the album" : "Ort des Albums",
    "Back" : "Zurück",
    "Add collaborators" : "Mitbearbeitende hinzufügen",
    "Save" : "Speichern",
    "Create album" : "Album erstellen",
    "Add to Album" : "Zum Album hinzufügen",
    "Add selection to album {albumName}" : "Auswahl zum Album {albumName} hinzufügen",
    "Shared by" : "Geteilt von",
    "Create a new album." : "Ein neues Album erstellen",
    "Create new album" : "Neues Album erstellen",
    "New album" : "Neues Album",
    "_%n item_::_%n photos and videos_" : ["%n Foto oder Video","%n Fotos und Videos"],
    "Add people or groups who can edit your album" : "Personen oder Gruppen hinzufügen, die dein Album bearbeiten können",
    "Search people or groups" : "Nach Benutzer oder Gruppen suchen",
    "No recommendations. Start typing." : "Keine Vorschläge, beginne mit der Eingabe.",
    "Group" : "Gruppe",
    "Remove {collaboratorLabel} from the collaborators list" : "{collaboratorLabel} aus der Liste der Mitarbeitenden löschen",
    "Copy the public link" : "Den öffentlichen Link kopieren",
    "Public link copied!" : "Öffentlicher Link kopiert",
    "Copy public link" : "Öffentlichen Link kopieren",
    "Delete the public link" : "Den öffentlichen Link löschen",
    "Create public link share" : "Öffentlichen Link zum Teilen erstellen",
    "Share via public link" : "Als öffentlichen Link teilen",
    "Failed to fetch collaborators list." : "Liste der Mitbearbeitenden konnte nicht abgerufen werden.",
    "Failed to update album." : "Album konnte nicht aktualisiert werden.",
    "This collection does not exist" : "Diese Sammlung existiert nicht",
    "An error occurred" : "Es ist ein Fehler aufgetreten",
    "_%n unassigned photo_::_%n unassigned photos_" : ["%n nicht zugewiesenes Foto","%n nicht zugewiesene Fotos"],
    "Favorite" : "Favorit",
    "Select image {imageName}" : "Bild {imageName} auswählen",
    "Open the full size \"{name}\" image" : "Bild \"{name}\" in Originalgröße öffnen",
    "Go back" : "Zurückgehen",
    "Back to {folder}" : "Zurück zu {folder}",
    "Share this folder" : "Diesen Ordner teilen",
    "Dates" : "Termine",
    "Add to {destination}" : "Hinzufügen zu {destination}",
    "There are no photos or videos yet!" : "Es gibt noch keine Fotos oder Videos!",
    "_{years} year ago_::_{years} years ago_" : ["Vor {years} Jahr","Vor {years} Jahren"],
    "Enable squared photos view" : "Quadratische Fotoansicht aktivieren",
    "Home" : "Startseite",
    "Choose default Photos upload and Albums location" : "Den Standardspeicherort für das Hochladen von Fotos und Alben wählen",
    "View" : "Ansicht",
    "_%n photo_::_%n photos_" : ["%n Foto","%n Fotos"],
    "Unselect all" : "Auswahl aufheben",
    "Manage collaborators for this album" : "Mitbearbeitende für dieses Album verwalten",
    "Open actions menu" : "Aktionsmenü öffnen",
    "Edit album details" : "Albumdetails bearbeiten",
    "Download all files in album" : "Alle Dateien im Album herunterladen",
    "Delete album" : "Album löschen",
    "Download selected files" : "Ausgewählte Dateien herunterladen",
    "Remove selection from album" : "Auswahl aus Album entfernen",
    "This album does not have any photos or videos yet!" : "Dieses Album enthält noch keine Fotos oder Videos!",
    "Add photos to this album" : "Fotos zu diesem Album hinzufügen",
    "Add photos to {albumName}" : "Fotos hinzufügen zu {albumName}",
    "Manage collaborators" : "Mitarbeitende verwalten",
    "Save collaborators for this album." : "Mitbearbeitende für dieses Album speichern.",
    "Cover photo for album {albumName}" : "Titelbild für Album {albumName}",
    "There is no album yet!" : "Es gibt noch kein Album!",
    "This person could not be found" : "Diese Person konnte nicht gefunden werden",
    "Rename person" : "Person umbenennen",
    "Merge with different person" : "Mit einer anderen Person zusammenführen",
    "Download selected photos" : "Ausgwählte Fotos herunterladen",
    "Remove from favorites" : "Von Favoriten entfernen",
    "Remove person" : "Person entfernen",
    "Name of this person" : "Name dieser Person",
    "Save." : "Speichern",
    "Merge person" : "Person zusammenführen",
    "Move to different person" : "Zu einer anderen Person umziehen",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Foto an eine andere Person verschieben","Fotos an eine andere Person verschieben"],
    "_Remove photo from person_::_Remove photos from person_" : ["Foto von Person entfernen","Fotos von Person entfernen"],
    "This might take some time depending on the size of your photo library." : "Dies kann je nach Größe deiner Fotobibliothek einige Zeit dauern.",
    "Recognized people will show up here" : "Erkannte Menschen werden hier angezeigt werden",
    "This folder does not exist" : "Dieser Ordner existiert nicht",
    "Loading folders …" : "Lade Ordner…",
    "No photos in here" : "Keine Fotos vorhanden",
    "Taken on {date} at {time}" : "Aufgenommen am {date} um {time}",
    "This place does not have any photos or videos yet!" : "Dieser Ort enthält noch keine Fotos oder Videos!",
    "Add photos to this place" : "Fotos zu diesem Ort hinzufügen",
    "Cover photo for place {placeName}" : "Titelbild für Ort {placeName}",
    "There is no place yet!" : "Es gibt noch keinen Ort",
    "Cover photo for shared album {albumName}." : "Titelbild für das geteilte Album {albumName}.",
    "Back to tags overview" : "Zurück zur Schlagwortübersicht",
    "No photos with this tag yet" : "Noch keine Fotos mit diesem Schlagwort",
    "No tags yet" : "Noch keine Schlagworte vorhanden",
    "Photos with tags will show up here" : "Fotos mit Tags werden hier angezeigt",
    "Popular tags" : "Beliebte Schlagwörter",
    "Add" : "Hinzufügen",
    "Add to album" : "Zum Album hinzufügen",
    "Delete selection" : "Auswahl löschen",
    "No photos or videos in here" : "Hier gibt es keine Fotos oder Videos.",
    "Unassigned faces" : "Nicht zugewiesene Gesichter",
    "_%n photos_::_%n photos_" : ["%n Foto","%n Fotos"],
    "Failed to fetch collection." : "Sammlung konnte nicht abgerufen werden.",
    "Failed to fetch collections list." : "Sammlungsliste konnte nicht geladen werden.",
    "Failed to fetch faces list." : "Liste mit Gesichter konnte nicht geladen werden.",
    "All your media" : "Alle deine Medien",
    "Album {title}" : "Album {title}",
    "Shared Albums" : "Geteilte Alben",
    "Shared album {title}" : "Geteiltes Album {title}",
    "Public album {title}" : "Öffentliches Album {title}",
    "Tagged photos" : "Fotos mit Tags",
    "Tagged photo {title}" : "Fotos mit Schlagworten",
    "{title}'s face" : "{title}´s Gesicht",
    "{startDate} to {endDate}" : "{startDate} bis {endDate}",
    "Details" : "Details",
    "Failed to rename {oldName} to {faceName}." : "{oldName} konnte nicht in {faceName} umbenannt werden.",
    "Failed to delete {faceName}." : "{faceName} konnte nicht gelöscht werden.",
    "Failed to delete {fileId}." : "{fileId} konnte nicht gelöscht werden.",
    "Failed to delete {fileName}." : "{fileName} konnte nicht gelöscht werden.",
    "Failed to set favorite state for {fileId}." : "Fehler beim Festlegen des Favoritenstatus für {fileId}.",
    "Failed to set favorite state for {fileName}." : "Fehler beim Festlegen des Favoritenstatus für {fileName}.",
    "Go back to the previous view." : "Zur vorherigen Ansicht zurückgehen",
    "Go to the add collaborators view." : "Zur Ansicht Mitbearbeitende-hinzufügen wechseln.",
    "Create the album." : "Das Album erstellen",
    "Back to the new album form." : "Zurück zur neuen Albumform",
    "_Share with %n user_::_Share with %n users_" : ["Mit %n Nutzer teilen","Mit %n Nutzern teilen"],
    "Search for collaborators" : "Suche nach Mitbearbeitenden",
    "Add {collaboratorLabel} to the collaborators list" : "{collaboratorLabel} zur Liste der Mitarbeitenden hinzufügen",
    "No collaborators available" : "Keine Mitarbeitenden verfügbar",
    "Failed to fetch album." : "Album konnte nicht abgerufen werden.",
    "The file is in the favorites" : "Die Datei ist in den Favoriten",
    "Open the \"{name}\" sub-directory" : "Öffne den \"{name}\" Unterordner",
    "Default Photos upload and Albums location" : "Standardspeicherort für das Hochladen von Fotos und Alben",
    "Select the default location for your media" : "Standardspeicherort für deine Medien auswählen",
    "Invalid location selected" : "Ungültiger Speicherort ausgewählt",
    "Photos directory" : "Verzeichnis für Fotos",
    "Add photos to the album" : "Fotos zum Album hinzufügen",
    "Failed to fetch albums list." : "Albumliste konnte nicht geladen werden.",
    "Shared albums" : "Geteilte Alben",
    "Create a new album" : "Neues Album erstellen",
    "Add selection to an album" : "Auswahl einem Album hinzufügen",
    "Failed to create {albumName}." : "{albumName} konnte nicht erstellt werden.",
    "Failed to rename {currentAlbumName} to {newAlbumName}." : "{currentAlbumName} konnte nicht in {newAlbumName} umbenannt werden."
},
"nplurals=2; plural=(n != 1);");
